@@ -39,6 +39,7 @@ namespace GAGGUI
 		size_t cursPos;
 		size_t maxLength;
 		bool password;
+		std::vector<std::string> autocompletableWord;
 	
 		// cache, recomputed at least on paint
 		GAGCore::Font *fontPtr;
@@ -56,13 +57,54 @@ namespace GAGGUI
 		virtual void paint(void);
 		void setText(const char *newText);
 		void setText(const std::string &newText) { setText(newText.c_str()); }
+		void setCursorPos(size_t pos){cursPos=pos;};
 		const char *getText(void) { return text.c_str(); }
 		const std::string &getTextStdString(void) { return text; }
 		void deactivate(void) { activated=false; recomputeTextInfos(); }
-		
+		/// adds word for autocompletion via <tab>
+		void addAutoCompletableWord(const std::string &word)
+		{
+			autocompletableWord.push_back(word);
+		};
+		/// removes word from autocompletion via <tab>
+		void removeAutoCompletableWord(const std::string &word)
+		{
+			std::vector<std::string>::iterator it;
+			for (it = autocompletableWord.begin(); it != autocompletableWord.end(); ++it)
+			{
+				if(*it==word)
+					autocompletableWord.erase(it);
+			}
+		}
+		/// returns the count of matching words for autocompletion for word and stores them to wordlist
+		bool getAutoCompleteSuggestion(const std::string & word, std::vector<std::string> & wordlist)
+		{
+			int count = 0;
+			std::vector<std::string>::iterator it;
+			for (it = autocompletableWord.begin(); it != autocompletableWord.end(); ++it)
+			{
+				if(*it==word)
+				{
+					count++;
+					wordlist.push_back(*it);
+				}
+			}
+			if(count>0)
+				return true;
+			return false;
+		};
+		/// returns the n-th suggestion
+		std::string getAutoComplete(const std::string & word, int n)
+		{
+			std::vector<std::string> wordlist;
+			if (getAutoCompleteSuggestion(word, wordlist)>0)
+				return wordlist.at(n);
+			return std::string("");
+		}
+
 	protected:
 		void recomputeTextInfos(void);
 	};
 }
 
-#endif 
+#endif
