@@ -100,8 +100,16 @@ namespace GAGCore
 		GLint _texture;
 		GLenum _sfactor, _dfactor;
 		bool isTextureRectangle;
+		bool useATIWorkaround;
 	
 		GLState(void)
+		{
+			resetCache();
+			isTextureRectangle = false;
+			useATIWorkaround = false;
+		}
+		
+		void resetCache(void)
 		{
 			_doBlend = -1;
 			_doTexture = -1;
@@ -109,7 +117,6 @@ namespace GAGCore
 			_texture = -1;
 			_sfactor = 0xffffffff;
 			_dfactor = 0xffffffff;
-			isTextureRectangle = false;
 		}
 		
 		void checkExtensions(void)
@@ -117,6 +124,12 @@ namespace GAGCore
 			const char *glExtensions = (const char *)glGetString(GL_EXTENSIONS);
 			isTextureRectangle = (strstr(glExtensions, "GL_NV_texture_rectangle") != NULL);
 			isTextureRectangle = isTextureRectangle || (strstr(glExtensions, "GL_EXT_texture_rectangle") != NULL);
+			isTextureRectangle = isTextureRectangle || (strstr(glExtensions, "GL_ARB_texture_rectangle") != NULL);
+
+			const char *glVendor= (const char *)glGetString(GL_VENDOR);
+			if(strstr(glVendor,"ATI"))
+				useATIWorkaround = true; // ugly temporary bug fix for bug 13823. We think it is an ATI driver bug
+
 			if (verbose)
 				if (isTextureRectangle)
 					std::cout << "Toolkit : GL_NV_texture_rectangle or GL_EXT_texture_rectangle extension present, optimal texture size will be used" << std::endl;
@@ -160,7 +173,11 @@ namespace GAGCore
 				return;
 		
 			if (isTextureRectangle)
+			{
+				if(useATIWorkaround)
+					glBindTexture(GL_TEXTURE_RECTANGLE_NV, 0);
 				glBindTexture(GL_TEXTURE_RECTANGLE_NV, tex);
+			}
 			else
 				glBindTexture(GL_TEXTURE_2D, tex);
 			_texture = tex;
@@ -342,7 +359,10 @@ namespace GAGCore
 	{
 		#ifdef HAVE_OPENGL
 		if (_gc->optionFlags & GraphicContext::USEGPU)
+		{
 			glDeleteTextures(1, reinterpret_cast<const GLuint*>(&texture));
+			glState.resetCache();
+		}
 		#endif
 	}
 	
@@ -937,7 +957,7 @@ namespace GAGCore
 	void DrawableSurface::drawCircle(int x, int y, int radius, Color color)
 	{
 		// clip
-		if ((x<clipRect.x) || (x>=clipRect.x+clipRect.w) || (y<clipRect.y) || (y>=clipRect.y+clipRect.h))
+		if ((x+radius < clipRect.x) || (x-radius >= clipRect.x+clipRect.w) || (y+radius < clipRect.y) || (y-radius >= clipRect.y+clipRect.h))
 			return;
 		
 		// draw
@@ -1013,6 +1033,7 @@ namespace GAGCore
 	{
 		if (alpha == Color::ALPHA_OPAQUE)
 		{
+			#ifdef HAVE_OPENGL
 			if ((surface == _gc) && (_gc->getOptionFlags() & GraphicContext::USEGPU))
 			{
 				if ((x == 0) && (y == 0) && (sdlsurface->w == sw) && (sdlsurface->h == sh))
@@ -1047,6 +1068,7 @@ namespace GAGCore
 			}
 			else
 			{
+			#endif // HAVE_OPENGL
 				// well, we *hope* SDL is faster than a handmade code
 				SDL_Rect sr, dr;
 				sr.x = static_cast<Sint16>(sx);
@@ -1058,7 +1080,9 @@ namespace GAGCore
 				dr.w = static_cast<Uint16>(sw);
 				dr.h = static_cast<Uint16>(sh);
 				SDL_BlitSurface(surface->sdlsurface, &sr, sdlsurface, &dr);
+			#ifdef HAVE_OPENGL	
 			}
+			#endif // HAVE_OPENGL
 		}
 		else
 		{
@@ -1753,6 +1777,11 @@ namespace GAGCore
 		}
 		else
 		{
+			#ifdef HAVE_OPENGL
+			if (optionFlags & USEGPU)
+				glState.checkExtensions();
+			#endif // HAVE_OPENGL
+			
 			setClipRect();
 			if (flags & CUSTOMCURSOR)
 			{
@@ -1774,7 +1803,6 @@ namespace GAGCore
 			#ifdef HAVE_OPENGL
 			if (optionFlags & USEGPU)
 			{
-				glState.checkExtensions();
 				gluOrtho2D(0, w, h, 0);
 				glEnable(GL_LINE_SMOOTH);
 				glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
@@ -1811,8 +1839,18 @@ namespace GAGCore
 	
 	void GraphicContext::printScreen(const char *filename)
 	{
-		if (sdlsurface)
-			SDL_SaveBMP(sdlsurface, filename);
+		#ifdef HAVE_OPENGL
+		if (_gc->optionFlags & GraphicContext::USEGPU)
+		{
+			DrawableSurface toPrint(getW(), getH());
+			glFlush();
+			toPrint.drawSurface(0, 0, this);
+			SDL_SaveBMP(toPrint.sdlsurface, filename);
+		}
+		else
+		#endif
+			if (sdlsurface)
+				SDL_SaveBMP(sdlsurface, filename);
 	}
 	
 	// Font stuff
