@@ -47,8 +47,9 @@ namespace Nicowar
 	///This constant turns on status output. status is output to the file "NicowarStatus.txt" in the current
 	///working directory. It has plenty of information that explains nicowars choices, which is good for
 	///fine tuning Nicowar as well as debugging it.
-	const bool NicowarStatusUpdate = false;
+	const bool NicowarStatusUpdate = true;
 
+	class AINicowar;
 	class Module;
 	class DefenseModule;
 	class AttackModule;
@@ -69,6 +70,7 @@ namespace Nicowar
 				Wood=1<<2,
 				Stone=1<<3,
 				TeamBuildings=1<<4,
+				Water=1<<5,
 			};
 
 			///This enum holds anything that can be an obstacle in the gradient
@@ -83,14 +85,17 @@ namespace Nicowar
 			///Constructs an invalid gradient
 			Gradient() {}
 			///Constructs a new gredient
-			Gradient(Team* team, unsigned sources, unsigned obstacles);
+			Gradient(AINicowar& team, unsigned sources, unsigned obstacles);
 			///Modifyies an existing gradient with new parameters
-			void reset(Team* team, unsigned sources, unsigned obstacles);
+			void reset(AINicowar& team, unsigned sources, unsigned obstacles);
 			///Updates the gradient from the given starting point outwards.
 			///Resources count as obstacles
 			void update();
 			///Gets the height of point x,y
-			unsigned getHeight(unsigned x, unsigned y);
+			int getHeight(int x, int y) const;
+
+			///Outputs the gradient to the console, warning, very large.
+			void output();
 		private:
 			bool isSource(unsigned x, unsigned y);
 			bool isObstacle(unsigned x, unsigned y);
@@ -100,6 +105,7 @@ namespace Nicowar
 			unsigned obstacles;
 			Team* team;
 			Map* map;
+			AINicowar* ai;
 			std::vector<short int> gradient;
 	};
 
@@ -109,8 +115,8 @@ namespace Nicowar
 	{
 		public:
 			GradientManager() {};
-			GradientManager(Team* team) : team(team) {}
-			void setTeam(Team* aTeam)
+			GradientManager(AINicowar* team) : team(team) {}
+			void setTeam(AINicowar* aTeam)
 			{
 				team=aTeam;
 			}
@@ -124,15 +130,15 @@ namespace Nicowar
 				unsigned obstacles;
 				bool operator<(const gradientSignature& cmp) const
 				{
-					if(sources<cmp.sources)
-						return true;
+					if(sources!=cmp.sources)
+						return sources<cmp.sources;
 					return obstacles<cmp.obstacles;
 				}
 			};
 
 			std::map<gradientSignature, Gradient> gradients;
 			std::queue<std::map<gradientSignature, Gradient>::iterator> update_queue;
-			Team* team;
+			AINicowar* team;
 
 	};
 
@@ -204,6 +210,10 @@ namespace Nicowar
 			{
 				orders.push(new MapMarkOrder(team->teamNumber, x, y));
 			}
+			void pause()
+			{
+				orders.push(new PauseGameOrder(true));
+			}
 		private:
 
 			std::map<std::string, std::map<std::string, std::map<std::string, std::vector<std::string> > > > debug_messages;
@@ -423,6 +433,10 @@ namespace Nicowar
 			///not have that ability, or have no skill in it.
 			unsigned int getUnits(unsigned int type, Unit::Medical medical_state, Unit::Activity activity, unsigned int ability, unsigned int level, bool isMinimum);
 
+			///Like the above method, this one returns the total number of units a person has meeting the criteria, not just ones
+			///that go for a particular health of activity level
+			unsigned int getUnits(unsigned int type, unsigned int ability, unsigned int level, bool isMinimum);
+
 			///Returns the highest level that the team has for a particular building type, or 0 for none.
 			unsigned int getMaximumBuildingLevel(unsigned int building_type);
 
@@ -482,32 +496,23 @@ namespace Nicowar
 	class UnitModule : public Module
 	{
 		public:
-			enum Priority
-			{
-				high=0,
-				medium_high,
-				medium,
-				medium_low,
-				low,
-				priorityNum,
-			};
 
 			///This function sets the maximum number of units the module wants for a specific unit type, level, and priority.
 			///This number must be the number of units the module would use, instantly, if granted them. This is with one
 			///exception, units with a low priority should simply be created, and do not need to be used imediettly. Its
 			///expectes that a module keep this number up to date, or the whole system can go down, because one module is being
 			///offered units and its never using them.
-			virtual void changeUnits(std::string moduleName, unsigned int unitType, unsigned int numUnits, unsigned int ability, unsigned int level, Priority priority)=0;
+			virtual void changeUnits(std::string moduleName, unsigned int unitType, unsigned int numUnits, unsigned int ability, unsigned int level)=0;
 
 			///This function returns the number of units available to the given module, based on the number of free units,
 			///how many units this module has already recieved, and how many it wants.
-			virtual unsigned int available(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int level, bool is_minimum, Priority priority)=0;
+			virtual unsigned int available(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int level, bool is_minimum)=0;
 
 			///This function returns true if the module can have the requested number of units for a specific task, and adds
 			///the building to the record books and manages the number of free units so that building can constantly keep full.
 			///This function can also be used to make changes on an existing building. Once you pass a building into UnitModule,
 			///the UnitModule will keep the building full untill you change the number of assigned units.
-			virtual bool request(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int minimum_level, unsigned int number, Priority priority, int building)=0;
+			virtual bool request(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int minimum_level, unsigned int number, int building)=0;
 
                         virtual void reserve(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int minimum_level, unsigned int number)=0;
                         virtual void unreserve(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int minimum_level, unsigned int number)=0;
@@ -726,6 +731,7 @@ namespace Nicowar
 				unsigned int y;
 				unsigned int assigned;
 				unsigned int building_type;
+				int no_build_timeout;
 			};
 
 			///Stores the percentage of buildings for a particular type there is.
@@ -737,14 +743,18 @@ namespace Nicowar
 				bool operator>(const typePercent& tp) const;
 			};
 
-			///Stores the information for a subgke factor in deciding where a building should be placed
+			///Stores the information for a single factor in deciding where a building should be placed
 			struct GradientPoll
 			{
 				GradientPoll() : is_null(true) {}
-				GradientPoll(Gradient::Sources source, float weight) : is_null(false), source(source), weight(weight) {}
-				bool is_null;
+				GradientPoll(Gradient::Sources source, Gradient::Obstacles obstacle, float weight) : is_null(false), source(source), obstacle(obstacle), weight(weight), min_dist(-1), max_dist(-1) {}
+				GradientPoll(Gradient::Sources source, Gradient::Obstacles obstacle, int minimum_distance, int maximum_distance) : is_null(false), source(source), obstacle(obstacle), weight(1), min_dist(minimum_distance), max_dist(maximum_distance) {}
+ 				bool is_null;
 				Gradient::Sources source;
+				Gradient::Obstacles obstacle;
 				float weight;
+				int min_dist;
+				int max_dist;
 			};
 
 			///Stores the various records of what is being built
@@ -890,11 +900,12 @@ namespace Nicowar
 			bool load(GAGCore::InputStream *stream, Player *player, Sint32 versionMinor);
 			void save(GAGCore::OutputStream *stream) const;
 
-			void changeUnits(std::string moduleName, unsigned int unitType, unsigned int numUnits, unsigned int ability, unsigned int level, Priority priority);
-			unsigned int available(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int level, bool is_minimum, Priority priority);
-			bool request(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int minimum_level, unsigned int number, Priority priority, int building);
+			void changeUnits(std::string moduleName, unsigned int unitType, unsigned int numUnits, unsigned int ability, unsigned int level);
+			unsigned int available(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int level, bool is_minimum);
+			bool request(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int minimum_level, unsigned int number, int building);
                         void reserve(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int minimum_level, unsigned int number);
                         void unreserve(std::string module_name, unsigned int unit_type, unsigned int ability, unsigned int minimum_level, unsigned int number);
+			void writeDebug();
 		protected:
 			///This stores all of the information needed for maintaining a particular building at its maximum unit consumption
 			struct usageRecord
@@ -908,7 +919,6 @@ namespace Nicowar
 				unsigned int unit_type;
 				unsigned int minimum_level;
 				unsigned int number;
-				Priority priority;
 			};
 
 			///This stores all of the buildings and how many units they are using. A buildings usage record is both stored
@@ -924,27 +934,32 @@ namespace Nicowar
 						for(int j=0; j<NB_ABILITY; ++j)
 							for(int k=0; k<NB_UNIT_LEVELS; ++k)
 							{
+								requested[i][j][k]=0;
+								usingUnits[i][j][k]=0;
 								reservedUnits[i][j][k]=0;
-								for(unsigned int l=0; l<priorityNum; ++l)
-								{
-									requested[i][j][k][l]=0;
-									usingUnits[i][j][k][l]=0;
-								}
 							}
 				}
 				///This is the number of requested units for various categories.
-				unsigned int requested[NB_UNIT_TYPE][NB_ABILITY][NB_UNIT_LEVELS][priorityNum];
+				unsigned int requested[NB_UNIT_TYPE][NB_ABILITY][NB_UNIT_LEVELS];
 				///This is the units that this module in particular is using for
-				unsigned int usingUnits[NB_UNIT_TYPE][NB_ABILITY][NB_UNIT_LEVELS][priorityNum];
+				unsigned int usingUnits[NB_UNIT_TYPE][NB_ABILITY][NB_UNIT_LEVELS];
 				///These are units that are reserved by the module, and will be transfered to a building soon
 				unsigned int reservedUnits[NB_UNIT_TYPE][NB_ABILITY][NB_UNIT_LEVELS];
 			};
 
+			int getUsagePercent(const std::string& module, int unit_type, int ability, int level);
+
+			std::string getMinModule(const std::string& bias, int unit_type, int ability, int level);
+
+			int getNeededUnits(int unit_type, int ability, int level, bool is_minimum);
+
 			///This map stores the moduleRecords in accordance to their related module
 			std::map<std::string, moduleRecord> module_records;
 
 			///Holds a refernece to the ai so taht the module can work properly.
 			AINicowar& ai;
+			std::map<int, std::string> unit_names;
+			std::map<int, std::string> ability_names;
 	};
 
 
@@ -972,9 +987,8 @@ namespace Nicowar
 			AINicowar& ai;
 	};
 
-	///The following deal with AINicowars management of explorers. It tries to explore areas covered with fog of war
-	///and, if it has enough exploreres with magic ground damage, it will launch deadly assaults on the enemy using
-	///explorers.
+	///The following deal with AINicowars management of explorers. For most of the time, it just orders the creation of explorers. But eventually,
+	///it will try to launch explorer attacks.
 	class ExplorationManager : public OtherModule
 	{
 		public:
@@ -986,60 +1000,19 @@ namespace Nicowar
 			void save(GAGCore::OutputStream *stream) const;
 			unsigned int numberOfTicks() const
 			{
-				return 4;
+				return 1;
 			}
-
-			///Stores a simple record of what areas are being explored and/or attacked.
-			struct explorationRecord
-			{
-				Building* flag;
-				unsigned int flag_x;
-				unsigned int flag_y;
-				unsigned int zone_x;
-				unsigned int zone_y;
-				unsigned int width;
-				unsigned int height;
-				unsigned int assigned;
-				unsigned int radius;
-				bool isAssaultFlag;
-			};
-			///Creates, destroys, or moves explorer flags to explore all of the hidden world.
-			///Important!! Each call to exploreWorld only manages changes (creates, destroys,
-			///or moves) one flag. So if many regions are desired to be explored at once, it
-			///may take several calls to exploreWorld to get them explored.
-			bool exploreWorld(void);
-
-			///When exploreWorld creates a new flag, it isn't able to get a link to the flag
-			///right away to be put into the active_exploration record list. So, instead, it
-			///adds in a NULL pointer, and this function will search out for exploration
-			///flags that have been create, that are not in the active_exploration record
-			///list yet. And it puts them there, as well as assigning them the right radius.
-			bool updateExplorationFlags(void);
-
 			///Controls the swarms in order to get the desired numbers of explorers. It puts
 			///the explorers creation at top priority, and if multiple explorers need to be
 			///created, will distribute them between its swarms.
 			bool moderateSwarmsForExplorers(void);
 
-			///Prepares and launches an explorer attack (if possible). Explorer attacks are
-			///where a group of level 4 explorers are assigned to an explorer flag over an
-			///area, who will spin around the permiter of the flag attack ground units. Can
-			///be devestating if not defended against properly.
-			bool explorerAttack(void);
-
-			///This list keeps a record of what regions are being explored, so when they're
-			///done being explored, it can move on to explore other regions.
-			std::list<explorationRecord> active_exploration;
-
-			///Checks if the given spot is free of flags.
-			bool isFreeOfFlags(unsigned int x, unsigned int y);
 
+			///Thisd is the number of explorers wanted
 			unsigned int explorers_wanted;
-			///True if explorers that are intended to be used in an attack are being created.
-			bool developing_attack_explorers;
-			///True if the conditions are right for an explorer attack.
-			bool explorer_attacking;
-
+			///This variable is only changed when the actual orders are sent to the unit module to request explorers,
+			///it keeps track of when numbers change so that the ai knows when to use UnitModule::reserve
+			unsigned int original_explorers_wanted;
 			///Holds a refernece to the ai so taht the module can work properly.
 			AINicowar& ai;
 	};
@@ -1161,12 +1134,50 @@ namespace Nicowar
 				return 2;
 			}
 
+			///Stores a single point on the map
+			struct point
+			{
+				point() {}
+				point(int x, int y) : x(x), y(y) {}
+				int x;
+				int y;
+				bool operator<(const point& cmp) const
+				{
+					if(x!=cmp.x)
+						return x<cmp.x;
+					return y<cmp.y;
+				}
+			};
+
+			struct fruitTreeRecord
+			{
+				unsigned int fruit_tree_max_x;
+				unsigned int fruit_tree_max_y;
+				unsigned int fruit_tree_min_y;
+				unsigned int fruit_tree_min_x;
+				int fruit_tree_type;
+			};
+
+			std::vector<fruitTreeRecord> fruit_trees;
+			bool is_fruit_trees_computed;
+			void computeFruitTrees();
+
+			struct fruitTreeExplorationRecord
+			{
+				unsigned flag;
+				int pos_x;
+				int pos_y;
+				unsigned radius;
+			};
+			std::vector<fruitTreeExplorationRecord> exploring_fruit_trees;
+
 			///This will change the alliances approprietly depending on the average happiness level.
 			bool adjustAlliances();
 
 			///Wil hunt out groups of fruit trees and put explorer flags on them
 			bool searchFruitTrees();
 
+
 			///Holds a refernece to the ai so taht the module can work properly.
 			AINicowar& ai;
 	};
@@ -1229,8 +1240,10 @@ namespace Nicowar
 			///area on that square, but no resource or if clearing area has been put over it
 			bool updateFarm();
 
-			///Holds a refernece to the ai so taht the module can work properly.
+			///Holds a reference to the ai so taht the module can work properly.
 			AINicowar& ai;
+			Gradient water_gradient;
+			bool is_water_gradient_computed;
 	};
 
 	///These constants are what fine tune AINicowar. There is allot of them.
@@ -1244,11 +1257,11 @@ namespace Nicowar
 	const unsigned int MAXIMUM_TO_UPGRADE=8;
 	const unsigned int MINIMUM_TO_REPAIR=2;
 	const unsigned int MAXIMUM_TO_REPAIR=8;
-	const unsigned int MAX_CONSTRUCTION_AT_ONCE=6;
+	const unsigned int BUILDINGS_FOR_UPGRADE=5;
 	const int MAX_BUILDING_SPECIFIC_CONSTRUCTION_LIMITS[IntBuildingType::NB_BUILDING]=
 		{0, 4, 2, 2, 2, 2, 2, 2, 0, 0, 0, 0, 0};
 	const unsigned int BUILDING_UPGRADE_WEIGHTS[IntBuildingType::NB_BUILDING]=
-		{0, 6, 6, 4, 4, 15, 6, 5, 0, 0, 0, 0, 0};
+		{0, 6, 8, 10, 10, 20, 10, 8, 0, 0, 0, 0, 0};
 
 	//The following constants deal with the function iteration. All of these must be
 	//lower than TIMER_ITERATION.
@@ -1256,31 +1269,10 @@ namespace Nicowar
 	const unsigned int STARTUP_TIME=50;
 
 	//These constants are for the AI's management of exploration and explorer attacks.
-	//Warning, the following four constants must be powers of 2, because map sizes are in powers of two,
-	//or the explorers will leave small strips at the right side of maps unexplored.
-	const unsigned int EXPLORER_REGION_WIDTH=16;
-	const unsigned int EXPLORER_REGION_HEIGHT=16;
-	const int EXPLORER_REGION_HORIZONTAL_OVERLAP=4;
-	const int EXPLORER_REGION_VERTICAL_OVERLAP=4;
-	const int EXPLORER_REGION_HORIZONTAL_EXTENTION=0;
-	const int EXPLORER_REGION_VERTICAL_EXTENTION=0;
-	//Its reccomended that this number is an even number.
-	const unsigned int EXPLORERS_PER_REGION=2;
-	const unsigned int EXPLORATION_FLAG_RADIUS=12;
-	const unsigned int EXPLORER_MAX_REGIONS_AT_ONCE=4;
+	const unsigned int TOTAL_EXPLORERS=8;
 
-	const unsigned int EXPLORER_ATTACK_AREA_WIDTH=8;
-	const unsigned int EXPLORER_ATTACK_AREA_HEIGHT=8;
-	const int EXPLORER_ATTACK_AREA_HORIZONTAL_OVERLAP=4;
-	const int EXPLORER_ATTACK_AREA_VERTICAL_OVERLAP=4;
-	const int EXPLORER_ATTACK_AREA_HORIZONTAL_EXTENTION=0;
-	const int EXPLORER_ATTACK_AREA_VERTICAL_EXTENTION=0;
-	const unsigned int EXPLORERS_PER_ATTACK=2;
-	const unsigned int EXPLORATION_FLAG_ATTACK_RADIUS=5;
-	const unsigned int EXPLORER_ATTACKS_AT_ONCE=4;
 
 	//These constants are for the AI's swarm controller.
-	const unsigned int PRIORITY_SCORES[UnitModule::priorityNum]={5, 4, 3, 2, 1};
 	//The number of units to assign to a swarm
 	const unsigned int MAXIMUM_UNITS_FOR_SWARM=5;
 
@@ -1346,44 +1338,71 @@ namespace Nicowar
 	const unsigned int BUILDING_PADDING=1;
 	const unsigned int NO_POSITION=1023;
 
-	const unsigned CONSTRUCTOR_FACTORS_COUNT=2;
+	const unsigned CONSTRUCTOR_FACTORS_COUNT=3;
 
 	const unsigned MAXIMUM_DISTANCE_TO_BUILDING=8;
 	typedef DistributedNewConstructionManager::GradientPoll GradientPoll;
 	const GradientPoll CONSTRUCTION_FACTORS[IntBuildingType::NB_BUILDING][CONSTRUCTOR_FACTORS_COUNT] = 
-		{{GradientPoll(Gradient::Wheat, 1), GradientPoll(Gradient::TeamBuildings, 1)}, //
-		 {GradientPoll(Gradient::Wheat, 1), GradientPoll(Gradient::TeamBuildings, 1)},
-		 {GradientPoll(Gradient::Wood, 1), GradientPoll(Gradient::TeamBuildings, 1)},
-		 {GradientPoll(Gradient::VillageCenter, 1), GradientPoll(Gradient::TeamBuildings, 1)},
-		 {GradientPoll(Gradient::VillageCenter, 1), GradientPoll(Gradient::TeamBuildings, 1)},
-		 {GradientPoll(Gradient::Stone, 1), GradientPoll(Gradient::TeamBuildings, 1)},
-		 {GradientPoll(Gradient::VillageCenter, 1), GradientPoll(Gradient::TeamBuildings, 1)},
-		 {GradientPoll(), GradientPoll()},
-		 {GradientPoll(), GradientPoll()},
-		 {GradientPoll(), GradientPoll()},
-		 {GradientPoll(), GradientPoll()},
-		 {GradientPoll(), GradientPoll()}};
+		{{	GradientPoll(Gradient::Wheat, Gradient::None, 2),
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1), 
+			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 0.5)}, //swarm
+
+		 {	GradientPoll(Gradient::Wheat, Gradient::None, 2), 
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1), 
+			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 0.5)}, //inn
+
+		 {	GradientPoll(Gradient::Wood, Gradient::None, 1), 
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1), 
+			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 0.5)}, //hospital
+
+		 {	GradientPoll(Gradient::VillageCenter, Gradient::Resource, 1), 
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
+			GradientPoll()}, //racetrack
+
+		 {	GradientPoll(Gradient::VillageCenter, Gradient::Resource, 1), 
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
+			GradientPoll()}, //swimming pool
+
+		 {	GradientPoll(Gradient::Stone, Gradient::None, 2), 
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1), 
+			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 0.5)}, //barracks
+
+		 {	GradientPoll(Gradient::VillageCenter, Gradient::Resource, 1), 
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
+			GradientPoll()}, //school
+
+		 {	GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1),
+			GradientPoll(),
+			GradientPoll()}, //Tower
+
+		 {	GradientPoll(), GradientPoll(), GradientPoll()},
+		 {	GradientPoll(), GradientPoll(), GradientPoll()},
+		 {	GradientPoll(), GradientPoll(), GradientPoll()},
+		 {	GradientPoll(), GradientPoll(), GradientPoll()}};
 
 
-	const unsigned int MAX_NEW_CONSTRUCTION_AT_ONCE=6;
+	///This represents for every n buildings the team has, allow one to be upgraded
+	const unsigned int MAX_NEW_CONSTRUCTION_AT_ONCE=8;
 	const unsigned int MAX_NEW_CONSTRUCTION_PER_BUILDING[IntBuildingType::NB_BUILDING] =
-		{2, 4, 3, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0};
-	const unsigned int MINIMUM_TO_CONSTRUCT_NEW=3;
+		{2, 4, 3, 1, 1, 2, 2, 2, 0, 0, 0, 0, 0};
+	const unsigned int MINIMUM_TO_CONSTRUCT_NEW=4;
 	const unsigned int MAXIMUM_TO_CONSTRUCT_NEW=8;
 	///How many units it requires to constitute construction another building, per type
 	const unsigned int UNITS_FOR_BUILDING[IntBuildingType::NB_BUILDING] =
-		{30, 8, 10, 20, 20, 15, 20, 0, 0, 0, 0, 0, 0};
+		{30, 12, 16, 80, 80, 30, 70, 30, 0, 0, 0, 0, 0};
 	///This is non-strict prioritizing, meaning that the priorities are used as multipliers on the percentages used
 	///for comparison. In otherwords, the lowest priorites will *almost* always be constructed first, however,
 	///in more extreme situations, higher priorites may be constructed first, even when its are missing lower
 	///priority buildings.
 	const unsigned int WEAK_NEW_CONSTRUCTION_PRIORITIES[IntBuildingType::NB_BUILDING] =
-		{4, 3, 4, 6, 6, 4, 6, 0, 0, 0, 0, 0};
+		{4, 2, 4, 6, 5, 4, 6, 5, 0, 0, 0, 0};
 	///Buildings with a higher strict priority will *always* go first
 	const unsigned int STRICT_NEW_CONSTRUCTION_PRIORITIES[IntBuildingType::NB_BUILDING] =
-		{2, 2, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0};
+		{2, 2, 2, 1, 1, 1, 1, 2, 0, 0, 0, 0};
 	///The number of turns before a cached no-build zone gets erased
 	const unsigned int NO_BUILD_CACHE_TIMEOUT=1;
+	///The number of turns before a building record that refers to a building that was destroyed before update gets removed
+	const unsigned int BUILDING_RECORD_TIMEOUT=5;
 
 	///This this enabled, buildings are constructed instantly, which is cheating,
 	///although can aid in debugging in certain situations
@@ -1396,12 +1415,15 @@ namespace Nicowar
 
 	//These constants are for HappinessHandler
 	const unsigned int EXPLORERS_PER_GROUP=2;
+	const unsigned int REQUESTED_EXPLORERES=4;
+	const unsigned int MINIMUM_FLAG_SIZE=3;
 
 	//These are for farmer
 	const Farmer::FarmingMethod FARMING_METHOD=Farmer::CrossSpacing;
+	const unsigned int MAX_DISTANCE_FROM_WATER=8;
 
 	///This constant turns on debugging output
-	const bool AINicowar_DEBUG = false;
+	const bool AINicowar_DEBUG = true;
 	///@}
 
 	//These are just some handy functions
@@ -1412,6 +1434,16 @@ namespace Nicowar
 		return syncRand()%x;
 	}
 
+	
+	inline bool buildingAttackPredicate(Building* a, Building* b)
+	{
+		if(a->constructionResultState==Building::NO_CONSTRUCTION && b->constructionResultState!=Building::NO_CONSTRUCTION)
+			return true;
+		else if(a->constructionResultState!=Building::NO_CONSTRUCTION && b->constructionResultState==Building::NO_CONSTRUCTION)
+			return false;
+		return syncRand()%2;
+	}
+
 	///Shuffles the given list.
 	template<typename T> void list_shuffle(std::list<T>& l)
 	{
