@@ -18,6 +18,7 @@
 */
 
 #include "AICastor.h"
+#include "AINicowar.h"
 
 #include <assert.h>
 #include <string.h>
@@ -947,24 +948,12 @@ bool Game::load(GAGCore::InputStream *stream)
 			teams[i]->integrity();
 		
 		// then script
-		ErrorReport er;
 		if (stream->canSeek())
 			stream->seekFromStart(tempSessionInfo.mapScriptOffset);
-		script.load(stream);
-		er=script.compileScript(this);
-		
-		if (er.type!=ErrorReport::ET_OK)
+		if (!script.load(stream, this))
 		{
-			if (er.type==ErrorReport::ET_NO_SUCH_FILE)
-			{
-				printf("SGSL : Can't find script file testscript.txt\n");
-			}
-			else
-			{
-				printf("SGSL : %s at line %d on col %d\n", er.getErrorString(), er.line+1, er.col);
-				stream->readLeaveSection();
-				return false;
-			}
+			stream->readLeaveSection();
+			return false;
 		}
 		
 		if (session.versionMinor < 37)
@@ -1056,7 +1045,7 @@ void Game::save(GAGCore::OutputStream *stream, bool fileIsAMap, const char* name
 		stream->write("GaPl", 4, "signatureAfterPlayers");
 
 		SAVE_OFFSET(stream, 32, "mapScriptOffset");
-		script.save(stream);
+		script.save(stream, this);
 		
 		stream->writeText(nextMap, "nextMap");
 		stream->writeText(campaignText, "campaignText");
@@ -1869,8 +1858,9 @@ void Game::drawMap(int sx, int sy, int sw, int sh, int viewportX, int viewportY,
 				
 				//globalContainer->gfx->drawString((x<<5), (y<<5), globalContainer->littleFont, ((AICastor *)players[1]->ai->aiImplementation)->notGrassMap[(x+viewportX)+(y+viewportY)*map.w]);
 				
-				globalContainer->gfx->drawString((x<<5), (y<<5), globalContainer->littleFont, map.getExplored(x+viewportX, y+viewportY, 0));
-				
+//				globalContainer->gfx->drawString((x<<5), (y<<5), globalContainer->littleFont, map.getExplored(x+viewportX, y+viewportY, 0));
+
+				globalContainer->gfx->drawString((x<<5), (y<<5), globalContainer->littleFont, ((Nicowar::AINicowar*)players[3]->ai->aiImplementation)->getGradientManager().getGradient(Nicowar::Gradient::VillageCenter, Nicowar::Gradient::Resource).getHeight(x+viewportX, y+viewportY));
 				//((AICastor *)players[0].ai->aiImplementation)->wheatCareMap
 			}
 				//if (map.getForbidden(x+viewportX, y+viewportY))
