@@ -282,7 +282,7 @@ void IRC::interpreteIRCMessage(const char *message)
 	else if (strcasecmp(cmd, "353")==0)
 	{
 		/*char *diffusion =*/ strtok(NULL, " ="); // strtok is used here for its side effects
-		char *chan = strtok(NULL, " :=");
+		char *chan = strtok(NULL, " :=*");
 		char *user;
 		while ((user = strtok(NULL, " :")) != NULL)
 		{
