@@ -180,7 +180,7 @@ void MultiplayersJoin::closeDownload()
 
 void MultiplayersJoin::dataPresenceRecieved(Uint8 *data, int size, IPaddress ip)
 {
-	if (size!=8)
+	if (size!=12)
 	{
 		fprintf(logFile, "Bad size for a Presence packet recieved!\n");
 		waitingState=WS_WAITING_FOR_PRESENCE;
@@ -190,13 +190,22 @@ void MultiplayersJoin::dataPresenceRecieved(Uint8 *data, int size, IPaddress ip)
 	}
 	
 	Uint8 serverNetProtocolVersion=data[4];
-	fprintf(logFile, "dataPresenceRecieved (serverNetProtocolVersion=%d)\n", serverNetProtocolVersion);
+	Uint32 serverConfigCheckSum=getUint32(data, 8);
+	fprintf(logFile, "dataPresenceRecieved (serverNetProtocolVersion=%d) (serverConfigCheckSum=%08x)\n",
+			serverNetProtocolVersion, serverConfigCheckSum);
 	
-	if (serverNetProtocolVersion!=NET_PROTOCOL_VERSION)
+	if (serverNetProtocolVersion!=NET_PROTOCOL_VERSION || serverConfigCheckSum!=globalContainer->getConfigCheckSum())
 	{
-		fprintf(logFile, " bad serverNetProtocolVersion!=%d)\n", NET_PROTOCOL_VERSION);
+		fprintf(logFile, " bad serverNetProtocolVersion!=%d or serverNetProtocolVersion!=%08x\n",
+				NET_PROTOCOL_VERSION, globalContainer->getConfigCheckSum());
 		if (shareOnYog)
-			yog->unjoinGame(false);
+		{
+			if (serverNetProtocolVersion != NET_PROTOCOL_VERSION)
+				yog->unjoinGame(false, Toolkit::getStringTable()->getString("[Can't join game, wrong game version]"));
+			else if (serverConfigCheckSum != globalContainer->getConfigCheckSum())
+				yog->unjoinGame(false, Toolkit::getStringTable()->getString("[Can't join game, missmatching game parameters]"));
+			
+		}
 		waitingState=WS_TYPING_SERVER_NAME;
 		waitingTimeout=0;
 		waitingTimeoutSize=0;
@@ -900,7 +909,7 @@ void MultiplayersJoin::joinerBroadcastRequest(Uint8 *data, int size, IPaddress i
 	memcpy(packet->data+5, playerName, l);
 	
 	if (SDLNet_UDP_Send(socket, -1, packet)==1)
-		fprintf(logFile, "send suceeded to send joinerBroadcastRequest packet to ip=(%s).\n", Utilities::stringIP(ip));
+		fprintf(logFile, "send suceeded to send joinerBroadcastRequest packet to ip=(%s). name=(%s), l=(%d)\n", Utilities::stringIP(ip), playerName, l);
 	else
 		fprintf(logFile, "send failed to send joinerBroadcastRequest packet to ip=(%s).\n", Utilities::stringIP(ip));
 	SDLNet_FreePacket(packet);
@@ -1356,7 +1365,7 @@ void MultiplayersJoin::sendingTime()
 			fprintf(logFile, "Last TOTL spent, server has left\n");
 			waitingState=WS_TYPING_SERVER_NAME;
 			if (shareOnYog)
-				yog->unjoinGame(false);
+				yog->unjoinGame(false, Toolkit::getStringTable()->getString("[Can't join game, timeout]"));
 			if (broadcastState==BS_ENABLE_YOG)
 				broadcastState=BS_DISABLE_YOG;
 			fprintf(logFile, "disabling NAT detection too. bs=(%d)\n", broadcastState);
@@ -1480,19 +1489,20 @@ void MultiplayersJoin::sendingTime()
 bool MultiplayersJoin::sendPresenceRequest()
 {
 	assert(BasePlayer::MAX_NAME_LENGTH==32);
-	UDPpacket *packet=SDLNet_AllocPacket(40);
+	UDPpacket *packet=SDLNet_AllocPacket(44);
 
 	assert(packet);
 
 	packet->channel=-1;
 	packet->address=serverIP;
-	packet->len=40;
+	packet->len=44;
 	packet->data[0]=NEW_PLAYER_WANTS_PRESENCE;
 	packet->data[1]=NET_PROTOCOL_VERSION;
 	packet->data[2]=0;
 	packet->data[3]=0;
-	addSint32(packet->data, (Sint32)ipFromNAT, 4);
-	strncpy((char *)(packet->data+8), playerName, 32); //TODO: use uid if over YOG.
+	addUint32(packet->data, globalContainer->getConfigCheckSum(), 4);
+	addSint32(packet->data, (Sint32)ipFromNAT, 8);
+	strncpy((char *)(packet->data+12), playerName, 32); //TODO: use uid if over YOG.
 
 	int nbsent=SDLNet_UDP_Send(socket, -1, packet);
 	if (nbsent==1)
