@@ -40,11 +40,13 @@ public:
 	
 	void load();
 	static void loadDefault();
+	static Uint32 checkSumDefault();
 	
 	UnitType *getUnitType(int type, int level);
 	
 	void save(GAGCore::OutputStream *stream);
 	bool load(GAGCore::InputStream *stream, Sint32 versionMinor);
+	Uint32 checkSum(void);
 	
 protected:
 	static Race defaultRace;
