@@ -20,7 +20,7 @@
 #ifndef __UNIT_H
 #define __UNIT_H
 
-#include <list>
+#include <vector>
 #include <assert.h>
 #include <string.h>
 
@@ -86,7 +86,7 @@ public:
 	void standardRandomActivity();
 	
 	int getRealArmor(void) const;
-	int getRealAttackStrength(void) const;
+	int getRealAttackStrength(void) const; //!< Return the real attack strengh for warriors
 	int getNextLevelThreshold(void) const;
 	void incrementExperience(int increment);
 	
@@ -201,6 +201,7 @@ public:
 	Movement movement;
 	Abilities action;
 	Sint32 targetX, targetY;
+	bool validTarget;
 	Sint32 magicActionTimeout;
 
 	// trigger parameters
@@ -236,7 +237,7 @@ public:
 
 public:
 	void integrity();
-	Uint32 checkSum(std::list<Uint32> *checkSumsList);
+	Uint32 checkSum(std::vector<Uint32> *checkSumsVector);
 	bool verbose;
 	
 protected:
