@@ -34,14 +34,21 @@ enum Abilities
 	ATTACK_SPEED=8,
 	
 	ATTACK_STRENGTH=9,
-	ARMOR=10,
-	HP=11,
 	
-	HEAL=12,
-	FEED=13
+	MAGIC_ATTACK_AIR=10,
+	MAGIC_ATTACK_GROUND=11,
+	MAGIC_CREATE_WOOD=12,
+	MAGIC_CREATE_CORN=13,
+	MAGIC_CREATE_ALGA=14,
+	
+	ARMOR=15, /* old 10 */
+	HP=16, /* old 11 */
+	
+	HEAL=17, /* old 12 */
+	FEED=18 /* old 13 */
 };
 const int NB_MOVE=9;
-const int NB_ABILITY=12;
+const int NB_ABILITY=17;
 
 
 const int WORKER=0;
