@@ -85,6 +85,7 @@ public:
 		bool fileIsAMap;
 		int mapGenerationMethode;
 		int netProtocolVersion;
+		Uint32 configCheckSum;
 		char mapName[64];
 		bool natSolved;
 		Uint32 huid; //the uid of the game host
@@ -142,7 +143,7 @@ public:
 	void unshareGame();
 	
 	void joinGame();
-	void unjoinGame(bool strict=true);
+	void unjoinGame(bool strict = true, const char *reason = NULL);
 	void joinGameRefused();
 	bool joinedGame;
 	
@@ -169,6 +170,8 @@ public:
 	IPaddress ipFromUserName(char userName[32]);
 	char *userNameFromUID(Uint32 uid);
 	
+	void addEventMessage(const char *msg);
+	
 	bool isConnectedToGameHost;
 	
 	YOGGlobalState yogGlobalState;
